This dataset is an example for NBBplot to show differential exons within genes between two conditions.
data("exondata")A data frame with 16 observations on the following 22 variables.
IDa factor with levels
ENSMUSG00000015597:E1
ENSMUSG00000015597:E10
ENSMUSG00000015597:E2
ENSMUSG00000015597:E3
ENSMUSG00000015597:E4
ENSMUSG00000015597:E5
ENSMUSG00000015597:E6
ENSMUSG00000015597:E7
ENSMUSG00000015597:E8
ENSMUSG00000015597:E9
ENSMUSG00000079547:E1
ENSMUSG00000079547:E2
ENSMUSG00000079547:E3
ENSMUSG00000079547:E4
ENSMUSG00000079547:E5
ENSMUSG00000079547:E6
chra numeric vector
elementa factor with levels exon
starta numeric vector
enda numeric vector
stranda factor with levels +
gene_ida factor with levels
ENSMUSG00000015597
ENSMUSG00000079547
exona numeric vector
genea factor with levels
H2-DMb1
Zfp318
WT_28a numeric vector
WT_43a numeric vector
A25_f0a numeric vector
cKO_30a numeric vector
A26_cKOa numeric vector
A6_f0a numeric vector
tva numeric vector
rhoa numeric vector
pvaluea numeric vector
wa numeric vector
order_numbera numeric vector
FDR0.05a numeric vector
significancea numeric vector
This dataset is an object of NBBttest and annoted with a R function. It contains columns start and end, gene,isoform, tv and pvalue, data, significance that NBBplut uses. WT and A25 are count data from wild type cell lines 28,43 and fo and A and cKO are also count data from knockout a gene, tv is t-statistic, rho is exon-wise variable and w is threshold of rho. Column "significance" is 1 if pvalue < FDR0.05, 0, otherwise. Gene Zfp318 has 10 exons and H2-DMb1 has 6 exons.
# NOT RUN {
data(exondata)
# }
Run the code above in your browser using DataLab