Data of RNA-seq reads were obtained from drug treated breast cancer in mice and mapped by using STAR onto mm10 to create count data. Dataset upGAm is output of NBBttest.
data("upGAm")A data frame with 263 observations on the following 19 variables.
genea factor with 263 DE genes
A.2_S35Sa numeric vector
A.4_S36Sa numeric vector
A.42_S45Sa numeric vector
A.39_S41Sa numeric vector
A.9_S44Ra numeric vector
A.12_S40Ra numeric vector
A.18_S37Ra numeric vector
A.29_S39Ra numeric vector
A.31_S38Ra numeric vector
A.38_S34Ra numeric vector
tvaluea numeric vector
rhoa numeric vector
pvaluea numeric vector
adjpa numeric vector
wa numeric vector
ordera numeric vector
FDRa numeric vector
significancea numeric vector
This dataset is a demo dataset having 263 DE genes identifiedby NBBttest. The dataset was created from types of two tomur cells: sensitive to drug(S) and resistant to drug (R). 4 sensitive cells and 6 resistant cells are available for differential analysis. Tvalue is t-statistic, \(\rho\) is gene-wise variable, pvalue is p-value for t-test, \(\omega\) is threshold for \(\rho\), FDR is false discovery rate, significance = 1 if pvalue < FDR, 0, otherwise.